@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Webmozart\Assert\Tests\StaticAnalysis;
 
 use Webmozart\Assert\Assert;
@@ -28,8 +30,6 @@ function nullOrLength(?string $value, int $length): ?string
  * @psalm-pure
  *
  * @param iterable<string> $value
- *
- * @return iterable<string>
  */
 function allLength(iterable $value, int $length): iterable
 {
@@ -42,8 +42,6 @@ function allLength(iterable $value, int $length): iterable
  * @psalm-pure
  *
  * @param iterable<string|null> $value
- *
- * @return iterable<string|null>
  */
 function allNullOrLength(iterable $value, int $length): iterable
 {
