@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Webmozart\Assert\Tests\StaticAnalysis;
 
 use Webmozart\Assert\Assert;
@@ -9,10 +11,8 @@ use Webmozart\Assert\Assert;
  *
  * @param mixed $value
  * @param mixed $limit
- *
- * @return mixed
  */
-function lessThanEq($value, $limit)
+function lessThanEq($value, $limit): mixed
 {
     Assert::lessThanEq($value, $limit);
 
@@ -24,10 +24,8 @@ function lessThanEq($value, $limit)
  *
  * @param mixed $value
  * @param mixed $limit
- *
- * @return mixed
  */
-function nullOrLessThanEq($value, $limit)
+function nullOrLessThanEq($value, $limit): mixed
 {
     Assert::nullOrLessThanEq($value, $limit);
 
@@ -39,10 +37,8 @@ function nullOrLessThanEq($value, $limit)
  *
  * @param mixed $value
  * @param mixed $limit
- *
- * @return mixed
  */
-function allLessThanEq($value, $limit)
+function allLessThanEq($value, $limit): mixed
 {
     Assert::allLessThanEq($value, $limit);
 
@@ -54,10 +50,8 @@ function allLessThanEq($value, $limit)
  *
  * @param mixed $value
  * @param mixed $limit
- *
- * @return mixed
  */
-function allNullOrLessThanEq($value, $limit)
+function allNullOrLessThanEq($value, $limit): mixed
 {
     Assert::allNullOrLessThanEq($value, $limit);
 
