@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Webmozart\Assert\Tests\StaticAnalysis;
 
 use Webmozart\Assert\Assert;
@@ -9,10 +11,8 @@ use Webmozart\Assert\Assert;
  *
  * @param class-string|object $classOrObject
  * @param mixed $method
- *
- * @return class-string|object
  */
-function methodExists($classOrObject, $method)
+function methodExists($classOrObject, $method): string|object
 {
     Assert::methodExists($classOrObject, $method);
 
@@ -24,10 +24,8 @@ function methodExists($classOrObject, $method)
  *
  * @param null|class-string|object $classOrObject
  * @param mixed $method
- *
- * @return null|class-string|object
  */
-function nullOrMethodExists($classOrObject, $method)
+function nullOrMethodExists($classOrObject, $method): string|object|null
 {
     Assert::nullOrMethodExists($classOrObject, $method);
 
@@ -39,8 +37,6 @@ function nullOrMethodExists($classOrObject, $method)
  *
  * @param iterable<class-string|object> $classOrObject
  * @param mixed $method
- *
- * @return iterable<class-string|object>
  */
 function allMethodExists(iterable $classOrObject, $method): iterable
 {
@@ -54,8 +50,6 @@ function allMethodExists(iterable $classOrObject, $method): iterable
  *
  * @param iterable<class-string|object|null> $classOrObject
  * @param mixed $method
- *
- * @return iterable<class-string|object|null>
  */
 function allNullOrMethodExists(iterable $classOrObject, $method): iterable
 {
