@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Webmozart\Assert\Tests\StaticAnalysis;
 
 use Webmozart\Assert\Assert;
@@ -7,10 +9,8 @@ use Webmozart\Assert\Assert;
 /**
  * @param mixed $value
  * @param mixed $expect
- *
- * @return mixed
  */
-function notEq($value, $expect)
+function notEq($value, $expect): mixed
 {
     Assert::notEq($value, $expect);
 
@@ -20,10 +20,8 @@ function notEq($value, $expect)
 /**
  * @param mixed $value
  * @param mixed $expect
- *
- * @return mixed
  */
-function nullOrNotEq($value, $expect)
+function nullOrNotEq($value, $expect): mixed
 {
     Assert::nullOrNotEq($value, $expect);
 
@@ -33,10 +31,8 @@ function nullOrNotEq($value, $expect)
 /**
  * @param mixed $value
  * @param mixed $expect
- *
- * @return mixed
  */
-function allNotEq($value, $expect)
+function allNotEq($value, $expect): mixed
 {
     Assert::allNotEq($value, $expect);
 
@@ -46,10 +42,8 @@ function allNotEq($value, $expect)
 /**
  * @param mixed $value
  * @param mixed $expect
- *
- * @return mixed
  */
-function allNullOrNotEq($value, $expect)
+function allNullOrNotEq($value, $expect): mixed
 {
     Assert::allNullOrNotEq($value, $expect);
 
