@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Webmozart\Assert\Tests\StaticAnalysis;
 
 use Webmozart\Assert\Assert;
@@ -13,7 +15,7 @@ use Webmozart\Assert\Assert;
  * @see https://github.com/vimeo/psalm/commit/4b715cdbffea19a7eab6f72482027d2dd358aab2
  * @see https://github.com/vimeo/psalm/issues/2456
  */
-function stringWillNotBeRedundantIfAssertingAndNotUsingEither($value): bool
+function stringWillNotBeRedundantIfAssertingAndNotUsingEither(mixed $value): bool
 {
     Assert::string($value);
 
